@@ -176,40 +176,45 @@ GNode *_hildon_file_system_get_locations(GtkFileSystem *fs)
 	g_node_append(virtual_node, rootnode);
 
         /* Setup safe folders */
-	if ((localpath = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES)) == NULL) {
+	if ((localpath = g_strdup(g_get_user_special_dir (G_USER_DIRECTORY_PICTURES))) == NULL) {
 	    localpath = g_build_path(G_DIR_SEPARATOR_S, rootpath, ".images", NULL);
 	}
 	setup_safe_folder(localpath, rootnode, 
             _("sfil_li_folder_images"), "filemanager_image_folder",
             HILDON_FILE_SYSTEM_MODEL_SAFE_FOLDER_IMAGES);
+	g_free(localpath);
 
-	if ((localpath = g_get_user_special_dir (G_USER_DIRECTORY_VIDEOS)) == NULL) {
+	if ((localpath = g_strdup(g_get_user_special_dir (G_USER_DIRECTORY_VIDEOS))) == NULL) {
 	    localpath = g_build_path(G_DIR_SEPARATOR_S, rootpath, ".videos", NULL);
 	}
         setup_safe_folder(localpath, rootnode, 
             _("sfil_li_folder_video_clips"), "filemanager_video_folder",
             HILDON_FILE_SYSTEM_MODEL_SAFE_FOLDER_VIDEOS);
+	g_free(localpath);
 
-	if ((localpath = g_get_user_special_dir (G_USER_DIRECTORY_MUSIC)) == NULL) {
+	if ((localpath = g_strdup(g_get_user_special_dir (G_USER_DIRECTORY_MUSIC))) == NULL) {
 	    localpath = g_build_path(G_DIR_SEPARATOR_S, rootpath, ".sounds", NULL);
 	}
         setup_safe_folder(localpath,rootnode, 
             _("sfil_li_folder_sound_clips"), "filemanager_audio_folder",
             HILDON_FILE_SYSTEM_MODEL_SAFE_FOLDER_SOUNDS);
+	g_free(localpath);
 
-	if ((localpath = g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS)) == NULL) {
+	if ((localpath = g_strdup(g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS))) == NULL) {
 	    localpath = g_build_path(G_DIR_SEPARATOR_S, rootpath, ".documents", NULL);
 	}
         setup_safe_folder(localpath, rootnode, 
             _("sfil_li_folder_documents"), "filemanager_document_folder",
             HILDON_FILE_SYSTEM_MODEL_SAFE_FOLDER_DOCUMENTS);
+	g_free(localpath);
 
-	if ((localpath = hildon_get_user_named_dir ("NOKIA_CAMERA_DIR")) == NULL) {
+	if ((localpath = g_strdup(hildon_get_user_named_dir ("NOKIA_CAMERA_DIR"))) == NULL) {
 	    localpath = g_build_path(G_DIR_SEPARATOR_S, rootpath, ".camera", NULL);
 	}
         setup_safe_folder(localpath, rootnode, 
             _("sfil_li_folder_camera"), "filemanager_camera_folder",
  	    HILDON_FILE_SYSTEM_MODEL_SAFE_FOLDER_CAMERA);
+	g_free(localpath);
 
         g_free(rootpath);
 
